@@ -7,6 +7,7 @@ from devops_toolset.devops_platforms.commands import Commands as CommonCommands
 from devops_toolset.devops_platforms.Literals import Literals as CommonLiterals
 from devops_toolset.devops_platforms.azuredevops.Literals import Literals as AzureDevOpsLiterals
 import devops_toolset.tools.cli as cli
+import logging
 
 app: App = App()
 commands = CommandsCore([CommonCommands])
@@ -28,5 +29,21 @@ def echo_environment_variable(environment_variable_name: str) -> str:
     ))
 
 
+def log_environment_variables(platform_keys: dict):
+    """Logs all environment variables for this platform and process.
+
+    Args:
+        platform_keys: dict with key-value pairs of platform variables.
+    """
+
+    spaces: int = len(max(platform_keys, key=len)) + 5
+
+    for key, value in platform_keys.items():
+        logging.info(literals.get("environment_variable_log").format(
+            key=str(key).ljust(spaces, "."),
+            value=value
+        ))
+
+
 if __name__ == "__main__":
     help(__name__)
