@@ -69,10 +69,16 @@ def generate_migration_sql_scripts_for_all_environments(
     """
 
     environments = utils.get_appsettings_environments(startup_project_path, include_development)
+    logging.info(literals.get("dotnet_ef_got_environments").format(environments=environments))
+
     base_path_obj = pathlib.Path(scripts_base_path)
 
     for environment in environments:
+        logging.info(literals.get("dotnet_ef_script_for_environment").format(environment=environment))
+
         script_path = pathlib.Path.joinpath(base_path_obj, f"database-migration-{environment.lower()}-from-#date#.sql")
+        logging.info(literals.get("dotnet_ef_script_being_generated").format(script_path=script_path))
+
         generate_migration_sql_script(startup_project_path, environment, str(script_path))
 
 
@@ -130,14 +136,18 @@ def __get_first_migration_not_applied(migrations_list: list) -> ([str, None], [s
         Tuple with migration name and migration date (migration format) or None
         and None if no migration is found.
     """
-
     regex_pattern = r"^(\d+)_[\w-]+$"
 
     for migration in migrations_list:
         if migration["applied"] is False:
             match = re.search(regex_pattern, migration["id"])
+            logging.info(literals.get("dotnet_ef_first_migration_not_applied").format(
+                migration_name=migration["name"],
+                migration_date=match.groups()[0]
+            ))
             return migration["name"], match.groups()[0]
 
+    logging.info(literals.get("dotnet_ef_no_pending_migrations"))
     return None, None
 
 
@@ -160,7 +170,7 @@ def __get_migrations_list(startup_project_path: str, environment: str, no_build:
         no_build="--no-build" if no_build else "",
         env=environment
     ))
-    logging.info(result)
+    logging.info(literals.get("dotnet_ef_migrations_list_output").format(output=result))
 
     migrations: str = ""
     json_lure: bool = False
@@ -191,6 +201,11 @@ def __parse_data_from_migrations_json_array(migrations_json_array: list) -> (int
             last_applied_migration = migration["id"]
             applied_migrations += 1
 
+    logging.info(literals.get("dotnet_ef_migrations_info").format(
+        number=len(migrations_json_array),
+        applied=applied_migrations,
+        name=last_applied_migration
+    ))
     return len(migrations_json_array), applied_migrations, last_applied_migration
 
 
